@@ -27,3 +27,6 @@
 #         driver.find_element_by_id('').click()
 #         assert_proxy('http;//***.***.com/***/***','userId')
 
+s = 'aaaaaa'
+
+print(s.count('a'))
\ No newline at end of file
